@@ -10,7 +10,7 @@
 Tests for extractor and updater or selected values from collections (limited tests from mock-data repos)
 """
 
-__docformat__ = "restructuredtext en"
+__docformat__ = "google en"
 __author__ = "John Westbrook"
 __email__ = "jwest@rcsb.rutgers.edu"
 __license__ = "Apache 2.0"
